@@ -1,4 +1,4 @@
-// Copyright (C) 2016-2018 John Donoghue <john.donoghue@ieee.org>
+// Copyright (C) 2016-2020 John Donoghue <john.donoghue@ieee.org>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -43,7 +43,8 @@ On success, setsockopt will return @var{status} of true \n \
 Known valid @var{optionid}s are:\n \
 @table @asis\n \
 @item @code{ZMQ_SUBSCRIBE}\n \
-Subscribe to incoming messages matching the value. The value is either a string or a uint8 array that must match the start of any incoming message\n \
+Subscribe to incoming messages matching the value. The value is either a string or a uint8 array that\n \
+must match the start of any incoming message\n \
 @item @code{ZMQ_UNSUBSCRIBE}\n \
 Unsubscribe from incoming messages\n \
 @item @code{ZMQ_CONNECT_TIMEOUT}\n \
@@ -61,19 +62,19 @@ Set the curve socket public key (string)\n \
 @item @code{ZMQ_CURVE_SERVERKEY}\n \
 Set the curve socket public key (string)\n \
 @item @code{ZMQ_PLAIN_SERVER}\n \
-Set whether socket server will use plain authenication (1) or not (0)\n \
+Set whether socket server will use plain authentication (1) or not (0)\n \
 @item @code{ZMQ_PLAIN_USERNAME}\n \
 Set the plain socket username (string)\n \
 @item @code{ZMQ_PLAIN_PASSWORD}\n \
 Set the plain socket password (string)\n \
 @item @code{ZMQ_GSSAPI_SERVER}\n \
-Set whether socket server will use gssi authenication (1) or not (0)\n \
+Set whether socket server will use gssapi authentication (1) or not (0)\n \
 @item @code{ZMQ_GSSAPI_PLAINTEXT}\n \
-Set whether socket will encrypt gssi authenication (1) or not (0)\n \
+Set whether socket will encrypt gssapi authentication (1) or not (0)\n \
 @item @code{ZMQ_GSSAPI_PRINCIPAL}\n \
-Set the name of the gssiapi principal (string)\n \
+Set the name of the gssapi principal (string)\n \
 @item @code{ZMQ_GSSAPI_SERVICE_PRINCIPAL}\n \
-Set the name of the gssiapi service principal (string)\n \
+Set the name of the gssapi service principal (string)\n \
 @end table\n \
 \n \
 @seealso {zmq_getsockopt, ZMQ_SUBSCRIBE, ZMQ_UNSUBSCRIBE, ZMQ_CONNECT_TIMEOUT}\n \
