@@ -78,6 +78,7 @@ octave_zeromq_socket::clone (void) const
 octave_base_value *
 octave_zeromq_socket::unique_clone (void) 
 {
+  count++;
   return this;
 }
 
@@ -473,29 +474,21 @@ octave_zeromq_socket::subsasgn (const std::string& type, const std::list<octave_
           ovl (0) = octave_value (this);
           ovl (1) = (idx.front ()) (0);
           ovl (2) = rhs;
-          OCTAVE__FEVAL (std::string ("__zmq_properties__"), ovl, 1);
- 
-          // property assignment
-          if (! error_state)
-            {
-              count++;
-              retval = octave_value (this);
-            }
+          OCTAVE__FEVAL (std::string ("__zmq_properties__"), ovl, 0);
+          count++;
+          retval = octave_value (this);
         }
       else if (type.length () > 1 && type[1] == '.')
         {
           // pass along any further assignments
           octave_value_list u = subsref (type.substr (0, 1), idx, 1);
-          if (! error_state)
+          if (u.length() > 0)
             {
               std::list<octave_value_list> next_idx (idx);
               next_idx.erase (next_idx.begin ());
               u (0).subsasgn(type.substr (1), next_idx, rhs);
-              if (!error_state)
-                {
-                  count++;
-                  retval = octave_value (this);
-                }
+              count++;
+              retval = octave_value (this);
             } 
         }
       else
